==> webkit2gtk_2.48.1.orig.tar.xz: webkitgtk-2.48.1/Source/WebCore/style/values/color/StyleKeywordColor.cpp <==
/*
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "StyleKeywordColor.h"

#include "CSSKeywordColor.h"
#include "Document.h"
#include "RenderStyle.h"
#include "RenderTheme.h"
#include "StyleBuilderState.h"
#include "StyleColor.h"
#include "StyleColorResolutionState.h"
#include "StyleCurrentColor.h"

namespace WebCore {
namespace Style {

Color toStyleColor(const CSS::KeywordColor& unresolved, ColorResolutionState& state)
{
    Ref protectedDocument = state.document;

    switch (unresolved.valueID) {
    case CSSValueInternalDocumentTextColor:
        return { protectedDocument->textColor() };
    case CSSValueWebkitLink:
        return { state.forVisitedLink == ForVisitedLink::Yes ? protectedDocument->visitedLinkColor(state.style) : protectedDocument->linkColor(state.style) };
    case CSSValueWebkitActivelink:
        return { protectedDocument->activeLinkColor(state.style) };
    case CSSValueWebkitFocusRingColor:
        return { RenderTheme::singleton().focusRingColor(protectedDocument->styleColorOptions(&state.style)) };
    case CSSValueCurrentcolor:
        return { CurrentColor() };
    default:
        return { CSS::colorFromKeyword(unresolved.valueID, protectedDocument->styleColorOptions(&state.style)) };
    }
}

} // namespace Style
} // namespace WebCore

==> webkit2gtk_2.51.92.orig.tar.xz: webkitgtk-2.51.92/Source/WebCore/style/values/color/StyleKeywordColor.cpp <==
/*
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "StyleKeywordColor.h"

#include "CSSKeywordColor.h"
#include "Document.h"
#include "RenderStyle.h"
#include "RenderTheme.h"
#include "StyleBuilderState.h"
#include "StyleColor.h"
#include "StyleColorResolutionState.h"
#include "StyleCurrentColor.h"

namespace WebCore {
namespace Style {

Color toStyleColor(const CSS::KeywordColor& unresolved, ColorResolutionState& state)
{
    Ref protectedDocument = state.document;

    switch (unresolved.valueID) {
    case CSSValueInternalDocumentTextColor:
        return { protectedDocument->textColor() };
    case CSSValueWebkitLink:
        return { state.forVisitedLink == ForVisitedLink::Yes ? protectedDocument->visitedLinkColor(state.style) : protectedDocument->linkColor(state.style) };
    case CSSValueWebkitActivelink:
        return { protectedDocument->activeLinkColor(state.style) };
    case CSSValueWebkitFocusRingColor:
        return { RenderTheme::singleton().focusRingColor(protectedDocument->styleColorOptions(state.style.ptr())) };
    case CSSValueCurrentcolor:
        return { CurrentColor() };
    default:
        return { CSS::colorFromKeyword(unresolved.valueID, protectedDocument->styleColorOptions(state.style.ptr())) };
    }
}

} // namespace Style
} // namespace WebCore
